emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 5ab146c: ; Revert some spelling fixes


From: Stefan Kangas
Subject: master 5ab146c: ; Revert some spelling fixes
Date: Fri, 16 Oct 2020 05:53:38 -0400 (EDT)

branch: master
commit 5ab146cf60392c84aff732a4c422cecfef7039d4
Author: Stefan Kangas <stefan@marxist.se>
Commit: Stefan Kangas <stefan@marxist.se>

    ; Revert some spelling fixes
    
    The preference was to keep the alternative spelling here, to ensure
    the documentation matches the name of the macros.
    This reverts part of commit 95e8c7d1d9.
    Ref: https://lists.gnu.org/r/emacs-devel/2020-10/msg00651.html
---
 lisp/cedet/semantic.el | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/lisp/cedet/semantic.el b/lisp/cedet/semantic.el
index 94bb7fa..71321e1 100644
--- a/lisp/cedet/semantic.el
+++ b/lisp/cedet/semantic.el
@@ -195,13 +195,13 @@ during a flush when the cache is given a new value of 
nil.")
 (make-variable-buffer-local 'semantic-parse-tree-state)
 
 (defmacro semantic-parse-tree-unparseable ()
-  "Indicate that the current buffer is unparsable.
+  "Indicate that the current buffer is unparseable.
 It is also true that the parse tree will need either updating or
 a rebuild.  This state will be changed when the user edits the buffer."
   '(setq semantic-parse-tree-state 'unparseable))
 
 (defmacro semantic-parse-tree-unparseable-p ()
-  "Return non-nil if the current buffer has been marked unparsable."
+  "Return non-nil if the current buffer has been marked unparseable."
   '(eq semantic-parse-tree-state 'unparseable))
 
 (defmacro semantic-parse-tree-set-needs-update ()
@@ -539,14 +539,14 @@ If the buffer cache is out of date, attempt an 
incremental reparse.
 If the buffer has not been parsed before, or if the incremental reparse
 fails, then parse the entire buffer.
 If a lexical error had been previously discovered and the buffer
-was marked unparsable, then do nothing, and return the cache."
+was marked unparseable, then do nothing, and return the cache."
   (and
    ;; Is this a semantic enabled buffer?
    (semantic-active-p)
    ;; Application hooks say the buffer is safe for parsing
    (run-hook-with-args-until-failure
     'semantic--before-fetch-tags-hook)
    ;; If the buffer was previously marked unparsable,
    ;; then don't waste our time.
    (not (semantic-parse-tree-unparseable-p))
    ;; The parse tree actually needs to be refreshed
@@ -617,7 +617,7 @@ Does nothing if the current buffer doesn't need reparsing."
   ;; do them here, then all the bovination hooks are not run, and
   ;; we save lots of time.
   (cond
    ;; If the buffer was previously marked unparsable,
    ;; then don't waste our time.
    ((semantic-parse-tree-unparseable-p)
     nil)
@@ -539,14 +539,14 @@ If the buffer cache is out of date, attempt an 
    (run-hook-with-args-until-failure
     'semantic--before-fetch-tags-hook)
-   ;; If the buffer was previously marked unparsable,
+   ;; If the buffer was previously marked unparseable,
    ;; then don't waste our time.
    (not (semantic-parse-tree-unparseable-p))
@@ -617,7 +617,7 @@ Does nothing if the current buffer doesn't need reparsing."
   ;; we save lots of time.
   (cond
-   ;; If the buffer was previously marked unparsable,
+   ;; If the buffer was previously marked unparseable,
    ;; then don't waste our time.
    ((semantic-parse-tree-unparseable-p)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]